@@ -1,37 +1,17 @@
+import os
 from urllib.parse import urljoin
 
-from pulp_smash import config
-from pulp_smash.pulp3.constants import (
-    BASE_DISTRIBUTION_PATH,
-    BASE_PUBLICATION_PATH,
-    BASE_REMOTE_PATH,
-    BASE_REPO_PATH,
-    BASE_CONTENT_PATH,
+
+PULP_FIXTURES_BASE_URL = os.environ.get(
+    "REMOTE_FIXTURES_ORIGIN", "https://fixtures.pulpproject.org/"
 )
 
-
-PULP_FIXTURES_BASE_URL = config.get_config().get_fixtures_url()
-
 PYPI_URL = "https://pypi.org/"
 
 PYTHON_CONTENT_NAME = "python.python"
 
-PYTHON_CONTENT_PATH = urljoin(BASE_CONTENT_PATH, "python/packages/")
-
-PYTHON_DISTRIBUTION_PATH = urljoin(BASE_DISTRIBUTION_PATH, "python/pypi/")
-
 PYTHON_FIXTURES_URL = urljoin(PULP_FIXTURES_BASE_URL, "python-pypi/")
 
-PYTHON_PUBLICATION_PATH = urljoin(BASE_PUBLICATION_PATH, "python/pypi/")
-
-PYTHON_REMOTE_PATH = urljoin(BASE_REMOTE_PATH, "python/python/")
-
-PYTHON_REPO_PATH = urljoin(BASE_REPO_PATH, "python/python/")
-
-PULP_CONTENT_HOST_BASE_URL = config.get_config().get_content_host_base_url()
-
-PULP_CONTENT_BASE_URL = urljoin(PULP_CONTENT_HOST_BASE_URL, "pulp/content/")
-
 PULP_PYPI_BASE_URL = "/pypi/"
 
 # Specifier for testing empty syncs, or no excludes
@@ -142,20 +122,21 @@ PYTHON_MD_PYPI_SUMMARY = {"projects": 4, "releases": 17, "files": 26}
 
 PYTHON_LG_PROJECT_SPECIFIER = [
     "aiohttp",  # matches 7
+    "bcrypt",  # matches 8
     "celery",  # matches 13
     "Django",  # matches 31
+    "pytz",  # matches 6
     "scipy",  # matches 23
     "setuptools",  # matches 2
     "shelf-reader",  # matches 2
 ]
-PYTHON_LG_PACKAGE_COUNT = 78
+PYTHON_LG_PACKAGE_COUNT = 92
 PYTHON_LG_FIXTURE_SUMMARY = {PYTHON_CONTENT_NAME: PYTHON_LG_PACKAGE_COUNT}
-PYTHON_LG_FIXTURE_PRERELEASES_SUMMARY = {PYTHON_CONTENT_NAME: 92}
 PYTHON_LG_FIXTURE_COUNTS = {
-    "latest_3": 37,
-    "sdist": 24,
-    "bdist_wheel": 54,
-    "multi": 26,  # keep_latest=1, package_types="bdist_wheel", prereleases=False
+    "latest_3": 51,
+    "sdist": 28,
+    "bdist_wheel": 64,
+    "multi": 34,  # keep_latest=1, package_types="bdist_wheel", prereleases=False
 }
 
 DJANGO_LATEST_3 = 4  # latest version has 2 dists, each other has 1
@@ -222,33 +203,34 @@ PYTHON_PACKAGE_DATA = {
     "classifiers": "[]",
 }
 
-# Info data for Shelf-reader
+# Info data for Shelf-reader, Not all the fields are the same whether uploaded or synced :(
+# pkginfo filters out 'UNKNOWN' values & fails to find a couple others due to package description
 PYTHON_INFO_DATA = {
     "name": "shelf-reader",
     "version": "0.1",
     # "metadata_version": "",  # Maybe program "1.1" into parse_metadata of app/utils.py
     "summary": "Make sure your collections are in call number order.",
-    "keywords": "library barcode call number shelf collection",
+    # "keywords": "library barcode call number shelf collection",
     "home_page": "https://github.com/asmacdo/shelf-reader",
-    "download_url": "UNKNOWN",
+    # "download_url": "UNKNOWN",
     "author": "Austin Macdonald",
     "author_email": "asmacdo@gmail.com",
     "maintainer": "",
     "maintainer_email": "",
     # "license": "GNU GENERAL PUBLIC LICENSE Version 2, June 1991",
     "requires_python": None,
-    "project_url": "https://pypi.org/project/shelf-reader/",
-    "platform": "UNKNOWN",
+    # "project_url": "https://pypi.org/project/shelf-reader/",
+    # "platform": "UNKNOWN",
     # "supported_platform": None,
     "requires_dist": None,
     # "provides_dist": [],
     # "obsoletes_dist": [],
     # "requires_external": [],
-    "classifiers": ['Development Status :: 4 - Beta', 'Environment :: Console',
-                    'Intended Audience :: Developers',
-                    'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
-                    'Natural Language :: English', 'Programming Language :: Python :: 2',
-                    'Programming Language :: Python :: 2.7'],
+    # "classifiers": ['Development Status :: 4 - Beta', 'Environment :: Console',
+    #                 'Intended Audience :: Developers',
+    #                 'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
+    #                 'Natural Language :: English', 'Programming Language :: Python :: 2',
+    #                 'Programming Language :: Python :: 2.7'],
     "downloads": {"last_day": -1, "last_month": -1, "last_week": -1},
     # maybe add description, license is long for this one
 }
